diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/area/AreaPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/area/AreaPluginBase.php
index fb747ea..ae87bd2 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/area/AreaPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/area/AreaPluginBase.php
@@ -40,22 +40,12 @@ public function init(ViewExecutable $view, &$options) {
     }
   }
 
-  /**
-   * Get this area's label.
-   */
-  public function label() {
-    if (!isset($this->options['label'])) {
-      return $this->adminLabel();
-    }
-    return $this->options['label'];
-  }
-
   protected function defineOptions() {
     $options = parent::defineOptions();
 
     $this->definition['field'] = !empty($this->definition['field']) ? $this->definition['field'] : '';
     $label = !empty($this->definition['label']) ? $this->definition['label'] : $this->definition['field'];
-    $options['label'] = array('default' => $label, 'translatable' => TRUE);
+    $options['admin_label']['default'] = $label;
     $options['empty'] = array('default' => FALSE, 'bool' => TRUE);
 
     return $options;
@@ -65,7 +55,7 @@ protected function defineOptions() {
    * Provide extra data to the administration form
    */
   public function adminSummary() {
-    return $this->label();
+    return $this->adminLabel();
   }
 
   /**
@@ -74,12 +64,9 @@ public function adminSummary() {
    */
   public function buildOptionsForm(&$form, &$form_state) {
     parent::buildOptionsForm($form, $form_state);
-    $form['label'] = array(
-      '#type' => 'textfield',
-      '#title' => t('Label'),
-      '#default_value' => isset($this->options['label']) ? $this->options['label'] : '',
-      '#description' => t('The label for this area that will be displayed only administratively.'),
-    );
+
+    unset($form['admin_label']['#fieldset']);
+    $form['admin_label']['#weight'] = -1;
 
     if ($form_state['type'] != 'empty') {
       $form['empty'] = array(
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php
index c272180..ac986c1 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/display/DisplayPluginBase.php
@@ -887,12 +887,7 @@ public function getFieldLabels() {
 
     $options = array();
     foreach ($this->getHandlers('relationship') as $relationship => $handler) {
-      if ($label = $handler->label()) {
-        $relationships[$relationship] = $label;
-      }
-      else {
-        $relationships[$relationship] = $handler->adminLabel();
-      }
+      $relationships[$relationship] = $handler->adminLabel();
     }
 
     foreach ($this->getHandlers('field') as $id => $handler) {
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/relationship/RelationshipPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/relationship/RelationshipPluginBase.php
index f1641aa..4f1264a 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/relationship/RelationshipPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/relationship/RelationshipPluginBase.php
@@ -61,20 +61,9 @@ public function init(ViewExecutable $view, &$options) {
     }
   }
 
-  /**
-   * Get this field's label.
-   */
-  function label() {
-    if (!isset($this->options['label'])) {
-      return $this->adminLabel();
-    }
-    return $this->options['label'];
-  }
-
   protected function defineOptions() {
     $options = parent::defineOptions();
 
-
     // Relationships definitions should define a default label, but if they aren't get another default value.
     if (!empty($this->definition['label'])) {
       $label = $this->definition['label'];
@@ -83,7 +72,7 @@ protected function defineOptions() {
       $label = !empty($this->definition['field']) ? $this->definition['field'] : $this->definition['base field'];
     }
 
-    $options['label'] = array('default' => $label, 'translatable' => TRUE);
+    $options['admin_label']['default'] = $label;
     $options['required'] = array('default' => FALSE, 'bool' => TRUE);
 
     return $options;
@@ -95,13 +84,9 @@ protected function defineOptions() {
    */
   public function buildOptionsForm(&$form, &$form_state) {
     parent::buildOptionsForm($form, $form_state);
-    $form['label'] = array(
-      '#type' => 'textfield',
-      '#title' => t('Identifier'),
-      '#default_value' => isset($this->options['label']) ? $this->options['label'] : '',
-      '#description' => t('Edit the administrative label displayed when referencing this relationship from filters, etc.'),
-      '#required' => TRUE,
-    );
+
+    unset($form['admin_label']['#fieldset']);
+    $form['admin_label']['#weight'] = -1;
 
     $form['required'] = array(
       '#type' => 'checkbox',
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/row/RowPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/row/RowPluginBase.php
index b18ded4..7ebcb9c 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/row/RowPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/row/RowPluginBase.php
@@ -89,7 +89,7 @@ public function buildOptionsForm(&$form, &$form_state) {
         $base = $data[$relationship['field']]['relationship']['base'];
         if ($base == $this->base_table) {
           $relationship_handler->init($executable, $relationship);
-          $relationship_options[$relationship['id']] = $relationship_handler->label();
+          $relationship_options[$relationship['id']] = $relationship_handler->adminLabel();
         }
       }
 
diff --git a/core/modules/views/views_ui/admin.inc b/core/modules/views/views_ui/admin.inc
index 5b0ae41..95e3334 100644
--- a/core/modules/views/views_ui/admin.inc
+++ b/core/modules/views/views_ui/admin.inc
@@ -816,7 +816,7 @@ function views_ui_rearrange_form($form, &$form_state) {
   // Get relationship labels
   $relationships = array();
   foreach ($display->getHandlers('relationship') as $id => $handler) {
-    $relationships[$id] = $handler->label();
+    $relationships[$id] = $handler->adminLabel();
   }
 
   // Filters can now be grouped so we do a little bit extra:
@@ -945,7 +945,7 @@ function views_ui_rearrange_filter_form($form, &$form_state) {
   // Get relationship labels
   $relationships = array();
   foreach ($display->getHandlers('relationship') as $id => $handler) {
-    $relationships[$id] = $handler->label();
+    $relationships[$id] = $handler->adminLabel();
   }
 
   $group_options = array();
@@ -1432,7 +1432,7 @@ function views_ui_config_item_form($form, &$form_state) {
         $base_fields = views_fetch_fields($base, $form_state['type'], $executable->display_handler->useGroupBy());
         if (isset($base_fields[$item['table'] . '.' . $item['field']])) {
           $relationship_handler->init($executable, $relationship);
-          $relationship_options[$relationship['id']] = $relationship_handler->label();
+          $relationship_options[$relationship['id']] = $relationship_handler->adminLabel();
         }
       }
 
diff --git a/core/modules/views/views_ui/lib/Drupal/views_ui/ViewEditFormController.php b/core/modules/views/views_ui/lib/Drupal/views_ui/ViewEditFormController.php
index 853d5c9..bc39ca1 100644
--- a/core/modules/views/views_ui/lib/Drupal/views_ui/ViewEditFormController.php
+++ b/core/modules/views/views_ui/lib/Drupal/views_ui/ViewEditFormController.php
@@ -894,7 +894,7 @@ public function getFormBucket(ViewUI $view, $type, $display) {
       // Get relationship labels
       $relationships = array();
       foreach ($view->get('executable')->displayHandlers[$display['id']]->getHandlers('relationship') as $id => $handler) {
-        $relationships[$id] = $handler->label();
+        $relationships[$id] = $handler->adminLabel();
       }
     }
 

diff --git a/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php b/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
index ff50f64..52cb149 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
@@ -68,13 +68,13 @@ public function testUI() {
 
       // Then setup a no empty label.
       $labels[$type] = $this->randomName();
-      $this->drupalPost($edit_path, array('options[label]' => $labels[$type]), t('Apply'));
+      $this->drupalPost($edit_path, array('options[admin_label]' => $labels[$type]), t('Apply'));
       // Make sure that the new label appears on the site.
       $this->assertText($labels[$type]);
 
       // Test that the settings (empty/label) are accessible.
       $this->drupalGet($edit_path);
-      $this->assertField('options[label]');
+      $this->assertField('options[admin_label]');
       if ($type !== 'empty') {
         $this->assertField('options[empty]');
       }
@@ -123,7 +123,6 @@ public function testTitleArea() {
         'table' => 'views',
         'field' => 'title',
         'admin_label' => '',
-        'label' => '',
         'empty' => '0',
         'title' => 'Overridden title',
       ),
@@ -68,13 +68,13 @@ public function testUI() {
       $this->assertText($labels[$type]);
 
-      // Test that the settings (empty/label) are accessible.
+      // Test that the settings (empty/admin_label) are accessible.
       $this->drupalGet($edit_path);